Index: src/compiler/all-nodes.h |
diff --git a/src/compiler/all-nodes.h b/src/compiler/all-nodes.h |
index 36f02e958256853e619c9ebdec0c48d4ed90d873..24a63b239dd2089d4a09e6673955b651e41ea063 100644 |
--- a/src/compiler/all-nodes.h |
+++ b/src/compiler/all-nodes.h |
@@ -16,9 +16,13 @@ namespace compiler { |
// from end. |
class AllNodes { |
public: |
- // Constructor. Traverses the graph and builds the {reachable} sets. When |
- // {only_inputs} is true, find the nodes reachable through input edges; |
- // these are all live nodes. |
+ // Constructor. Traverses the graph and builds the {reachable} set of nodes |
+ // reachable from {end}. When {only_inputs} is true, find the nodes |
+ // reachable through input edges; these are all live nodes. |
+ AllNodes(Zone* local_zone, Node* end, const Graph* graph, |
+ bool only_inputs = true); |
+ // Constructor. Traverses the graph and builds the {reachable} set of nodes |
+ // reachable from the End node. |
AllNodes(Zone* local_zone, const Graph* graph, bool only_inputs = true); |
bool IsLive(Node* node) { |
@@ -35,6 +39,8 @@ class AllNodes { |
NodeVector reachable; // Nodes reachable from end. |
private: |
+ void Mark(Zone* local_zone, Node* end, const Graph* graph); |
+ |
BoolVector is_reachable_; |
const bool only_inputs_; |
}; |